#
# spec file for package libpanel
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define libname %{name}-1-1

Name:           libpanel
VCS: https://src.suse.de/SLFO-pool/libpanel#391d5c7503d72cb0514817091b8dc21241f4bb1c10a372d987e50af932cb044a
Version:        1.10.0
Release:        160000.1.1
Summary:        IDE paneling library for GTK
License:        LGPL-3.0-or-later
URL:            https://gitlab.gnome.org/GNOME/libpanel
Source:         %{name}-%{version}.tar.zst

%if 0%{?sle_version} && 0%{?sle_version} < 160000
BuildRequires:  gcc13
BuildRequires:  gcc13-c++
%endif
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(gtk4)
BuildRequires:  pkgconfig(libadwaita-1)
BuildRequires:  pkgconfig(vapigen)

%description
A collection of GTK widgets for IDE-like applications targeting
GNOME using GTK and libadwaita.

%package -n     %{libname}
Summary:        Shared library files for %{name}
Provides:       %{name} = %{version}
Provides:       %{name}1-1
Obsoletes:      %{name}1-1

%description -n %{libname}
The %{libname} package contains shared libraries %{name}.

%package -n     typelib-1_0-Panel-1
Summary:        Typelib files for %{name}

%description -n typelib-1_0-Panel-1
Package contains typelib files for use with %{name}.

%package        devel
Summary:        Development files for %{name}
Requires:       %{libname} = %{version}
Requires:       typelib-1_0-Panel-1 = %{version}

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%lang_package

%prep
%autosetup -p1

%build
%if 0%{?sle_version} && 0%{?sle_version} < 160000
export CC=gcc-13
%endif
%meson \
	-D docs=disabled \
	%{nil}
%meson_build

%install
%meson_install
%find_lang %{name}

%ldconfig_scriptlets -n %{libname}

%files -n %{libname}
%license COPYING
%{_libdir}/%{name}-1.so.*

%files -n typelib-1_0-Panel-1
%{_libdir}/girepository-1.0/Panel-1.typelib

%files devel
%doc AUTHORS NEWS README.md
%{_includedir}/libpanel-1/
%{_libdir}/libpanel-1.so
%{_libdir}/pkgconfig/libpanel-1.pc
%dir %{_datadir}/gir-1.0
%{_datadir}/gir-1.0/Panel-1.gir
%{_datadir}/icons/hicolor/scalable/actions/panel-*-symbolic.svg
%dir %{_datadir}/vala
%dir %{_datadir}/vala/vapi
%{_datadir}/vala/vapi/libpanel-1.deps
%{_datadir}/vala/vapi/libpanel-1.vapi

%files lang -f %{name}.lang

%changelog
* Sun Mar 16 2025 bjorn.lie@gmail.com
- Update to version 1.10.0:
  + OmniBar has received a fix for changes to AdwClamp.
* Sun Feb  2 2025 bjorn.lie@gmail.com
- Update to version 1.9.0 (Unstable):
  + Various style improvements to match libadwaita
  + Various drag-n-drop improvements
  + Remove some deprecated API use
  + Updated translations.
* Sat Oct 19 2024 bjorn.lie@gmail.com
- Update to version 1.8.1:
  + Fix DnD of widgets in cases where libadwaita holds reference
    via AdwBin.
* Sun Sep 15 2024 bjorn.lie@gmail.com
- Update to version 1.8.0:
  + Updated translations.
- Changes from version 1.7.1:
  + Various dialog improvements
  + Build system improvements
  + Updated translations.
- Changes from version 1.7.0:
  + Style fixes for libadwaita 1.6.alpha
  + A new PanelChangesDialog which is an AdwDialog but is
    otherwise like PanelSaveDialog. PanelSaveDialog is now
    deprecated for what will become 1.8+.
  + Updated translations.
* Sat Mar 16 2024 dimstar@opensuse.org
- Update to version 1.6.0:
  + Updated translations.
* Mon Mar  4 2024 dimstar@opensuse.org
- Update to version 1.5.1:
  + Fix CSS clipping with frame switcher buttons.
  + Updated translations.
* Mon Feb 19 2024 dimstar@opensuse.org
- Update to version 1.5.0:
  + Improvements to PanelDockChild which allow attaching edge
    widgets. This can be used to create more natural sidebar
    styling as is used by GNOME Builder for GNOME 46.
  + Initial state fixes for various panels.
  + PanelThemeSelector focus fixes.
  + AdwTabBar usage will only create start area when necessary
    fixing some initial styling issues.
* Mon Feb  5 2024 yfjiang@suse.com
- Choose higher gcc version to build on SLE and Leap 15.
- Update the name of libpanel-1-1 to be compliant with:
  https://en.opensuse.org/openSUSE:Shared_library_packaging_policy
* Sun Sep 17 2023 luc14n0@opensuse.org
- Update to version 1.4.0:
  + Stylesheet fixes for GNOME 45.
  + Updated translations.
* Sun Sep  3 2023 luc14n0@opensuse.org
- Update to version 1.3.1:
  + A11y improvements.
- Replace pkgconfig(glib-2.0) BuildRequires with pkgconfig(gio-2.0)
  to follow upstream change.
* Thu Aug 10 2023 bjorn.lie@gmail.com
- Update to version 1.3.0:
  + A PanelMenuManager has been added
  + An action group helper has been added
  + The action muxer API is now public
  + A layered gsettings helper is available
  + An inhibitor api is provided for session logout inhibiting
  + A new workspace/workbench API is provided that is similar to
    what Builder has done
  + Various bug fixes
* Fri Mar 17 2023 bjorn.lie@gmail.com
- Update to version 1.2.0:
  + CSS fixes for libadwaita 1.4.
  + Fix various gidoc warnings.
  + Remove use of g_autoptr() which creeped in.
  + Updated translations.
* Mon Mar  6 2023 bjorn.lie@gmail.com
- Update to version 1.1.2:
  + Fix various leaks
  + Improved gir annoations
  + Docs cleanup
  + Fixes for use with AdwTabView
  + Updated translations.
* Thu Feb 23 2023 bjorn.lie@gmail.com
- Update to version 1.1.1:
  + Tooltip improvements.
  + Improved page closed handling.
  + PanelDock::create-frame(position) signal was added.
  + PanelDock::adpot-widget() signal was added.
  + Correctness fixes in PanelActionMuxer.
  + Improved i18n support.
  + Updated translations.
- Changes from version 1.1.0:
  + DnD fixes.
  + PanelWidget:tooltip property to set tooltips on tabs.
  + Disable ctrl+home/end from adwaita for tabs by default.
  + CSS tweaks.
  + A new frame.close-all action.
  + Updated translations.
* Thu Nov  3 2022 bjorn.lie@gmail.com
- Update to version 1.0.2:
  + CSS improvements for backdrop.
  + Block tabbar from handling ctrl+home and similar shortcuts.
* Tue Sep 27 2022 bjorn.lie@gmail.com
- Update to version 1.0.1:
  + Drag-n-Drop fixes.
  + Remove use of g_autofree to fix builds for MSVC.
  + Updated translations.
* Sun Sep 18 2022 bjorn.lie@gmail.com
- Update to version 1.0.0:
  + Various dock improvements to grabs.
  + Switch to GBindingGroup.
  + PanelSaveChangesDialog implements the new GNOME save workflow.
  + PanelPosition has been added.
  + Improvements to PanelFrame.
  + PanelDockPosition has been renamed to PanelArea.
  + PanelDockSwitcher has been renamed to PanelToggleButton.
  + Various convenience API additions.
  + Documentation updates.
  + Updated translations.
- Pass docs=disabled to meson, do not build api docs for now.
- Package translations, and provide libpanel via the main shared
  library, make lang-package installable.
* Sat Aug 20 2022 bjorn.lie@gmail.com
- Initial packaging for openSUSE.
